@@ -57,18 +57,10 @@ $(document).ready(function() {
             }
             ,function(data) {
                 if (data == 'marked') {
-                    // Get only unread notifications from first notification wrapper
-                    // In case you are watching both, list view and tag, only one of them is tracked
-                    var unread_notifs = $('[data-class="notifications"]').first().find('[data-class="notification"].unread');
-                    var unread_amount = $('[data-id="notification-unread"]').text();
-
-                    // Remove all unread classes, though
+                    // Remove all unread classes
                     $('[data-class="notification"].unread').removeClass('unread');
-                    if ((unread_amount - unread_notifs.length) <= 1) {
-                        $('[data-id="notification-unread"]').removeClass('unread');
-                    }
-                    $('[data-id="notification-unread"]').text(unread_amount - unread_notifs.length);
-                    checkUnreadNotifications();
+                    $('[data-id="notification-unread"]').removeClass('unread');
+                    $('[data-id="notification-unread"]').text('0');
                 }
             }
         );
